@@ -1,5 +1,6 @@
 from __future__ import annotations
 
+from functools import partial
 from inspect import getmembers, isclass, isfunction
 from typing import Any, Callable, Dict, Optional, Tuple, Type, get_type_hints
 
@@ -58,6 +59,8 @@ def _setup_signature_registry(
         nonlocal registry
 
         for route in app.router.routes:
+            if ".openapi." in route.name:
+                continue
             handlers = [(route.name, route.handler)]
             viewclass = getattr(route.handler, "view_class", None)
             if viewclass:
@@ -68,6 +71,13 @@ def _setup_signature_registry(
                     )
                 ]
             for name, handler in handlers:
+                if hasattr(handler, "__auto_handler__"):
+                    continue
+                if isinstance(handler, partial):
+                    if handler.func == app._websocket_handler:
+                        handler = handler.args[0]
+                    else:
+                        handler = handler.func
                 try:
                     hints = get_type_hints(handler)
                 except TypeError:
