@@ -2,7 +2,7 @@ import json
 import uuid
 from datetime import date, datetime, time
 from enum import Enum
-from inspect import isclass
+from inspect import getmembers, isfunction
 from typing import (
     Any,
     Dict,
@@ -74,6 +74,7 @@ class Schema(Definition):
     anyOf: List[Definition]
     allOf: List[Definition]
 
+    additionalProperties: Dict[str, str]
     multipleOf: int
     maximum: int
     exclusiveMaximum: bool
@@ -158,6 +159,13 @@ class Schema(Definition):
             return Array(schema, **kwargs)
         elif _type == dict:
             return Object.make(value, **kwargs)
+        elif (
+            (is_generic(value) or is_generic(_type))
+            and origin == dict
+            and len(args) == 2
+        ):
+            kwargs["additionalProperties"] = Schema.make(args[1])
+            return Object(**kwargs)
         elif (is_generic(value) or is_generic(_type)) and origin == list:
             return Array(Schema.make(args[0]), **kwargs)
         elif _type is type(Enum):
@@ -301,13 +309,28 @@ def _serialize(value) -> Any:
 
 def _properties(value: object) -> Dict:
     try:
-        fields = {x: v for x, v in value.__dict__.items()}
+        fields = {
+            x: val
+            for x, v in getmembers(value, _is_property)
+            if (val := _extract(v))
+        }
     except AttributeError:
         fields = {}
 
-    cls = value if isclass(value) else value.__class__
+    cls = value if callable(value) else value.__class__
     return {
         k: v
         for k, v in {**get_type_hints(cls), **fields}.items()
         if not k.startswith("_")
     }
+
+
+def _extract(item):
+    if isinstance(item, property):
+        hints = get_type_hints(item.fget)
+        return hints.get("return")
+    return item
+
+
+def _is_property(item):
+    return not isfunction(item)
